## ----include = FALSE----------------------------------------------------------
knitr::opts_chunk$set(
  collapse = TRUE,
  message = FALSE,
  comment = "#>"
  #fig.width = 8,
  #fig.height = 8,
  #fig.retina = 2
)

## ----example_spe, eval = requireNamespace('SpotSweeper')----------------------
library(SpotSweeper)


# load  Maynard et al DLPFC daatset
spe <- STexampleData::Visium_humanDLPFC()

# change from gene id to gene names
rownames(spe) <- rowData(spe)$gene_name

# show column data before SpotSweeper
colnames(colData(spe))

# drop out-of-tissue spots
spe <- spe[, spe$in_tissue == 1]
spe <- spe[, !is.na(spe$ground_truth)]

## ----example_localOutliers, eval = requireNamespace('SpotSweeper')------------

# Identifying the mitochondrial transcripts in our SpatialExperiment.
is.mito <- rownames(spe)[grepl("^MT-", rownames(spe))]

# Calculating QC metrics for each spot using scuttle
spe<- scuttle::addPerCellQCMetrics(spe, subsets=list(Mito=is.mito))
colnames(colData(spe))

# Identifying local outliers using SpotSweeper
features <- c('sum' ,'detected', "subsets_Mito_percent")
spe<- localOutliers(spe, 
                    features=features,
                    n_neighbors=18, 
                    data_output=TRUE,
                    method="multivariate"
                    )

# show column data after SpotSweeper
colnames(colData(spe))


## ----local_outlier_plot-------------------------------------------------------
library(escheR)
library(ggpubr)

# plotting using escheR
p1 <- make_escheR(spe) |> 
  add_fill(var = "sum_log2", point_size=1.25) +
  scale_fill_gradient(low ="white",high =  "darkgreen")

p2 <- make_escheR(spe) |> 
  add_fill(var = "sum_log2", point_size=1.25) |>
  add_ground(var = "local_outliers", stroke = 1) +
  scale_color_manual(
    name = "", # turn off legend name for ground_truth
    values = c(
      "TRUE" = "red",
      "FALSE" = "transparent")
  ) +
  scale_fill_gradient(low ="white",high =  "darkgreen")

plot_list <- list(p1, p2)
ggarrange(
  plotlist = plot_list,
  ncol = 2, nrow = 1,
  common.legend = FALSE
)

## -----------------------------------------------------------------------------
utils::sessionInfo()

